@@ -32,6 +32,8 @@
 
 """|UDM| module for the windows hosts"""
 
+from typing import Any  # noqa: F401
+
 import univention.admin.filter
 import univention.admin.handlers
 import univention.admin.localization
@@ -289,16 +291,19 @@ class object(ComputerObject):
     SERVER_ROLE = 'windows_client'
 
     def _ldap_modlist(self):
+        # type: () -> list[tuple[str, Any, Any]]
         if self.hasChanged('ntCompatibility') and self['ntCompatibility'] == '1':
             self['password'] = self['name'].replace('$', '').lower()
             self.modifypassword = 1
         return super(object, self)._ldap_modlist()
 
     def link(self):
+        # type: () -> None
         pass
 
     @classmethod
     def lookup_filter(cls, filter_s=None, lo=None):
+        # type: (str | None, univention.admin.uldap.access | None) -> univention.admin.filter.conjunction
         con = super(object, cls).lookup_filter(filter_s, lo)
         con.expressions.append(univention.admin.filter.conjunction('!', [univention.admin.filter.expression('univentionServerRole', 'windows_domaincontroller')]))
         return con
@@ -309,4 +314,5 @@ lookup_filter = object.lookup_filter
 
 
 def identify(dn, attr, canonical=False):
+    # type: (str, univention.admin.handlers._Attributes, bool) -> bool
     return b'univentionHost' in attr.get('objectClass', []) and b'univentionWindows' in attr.get('objectClass', []) and b'windows_domaincontroller' not in attr.get('univentionServerRole', [])
